@@ -82,20 +82,20 @@ void DownloadManager::cancelDownload() {
 }
 
 void DownloadManager::startDownload(const QString &filePath, const QString &url) {
-    downloading = true;
+    setIsDownloading(true);
     output.setFileName(filePath + ".partial");
     if (output.exists()) {
         //        qDebug() << "File exists";
         if (!output.open(QIODevice::Append)) {
             //            qDebug() << "No write permissions";
-            downloading = false;
+            setIsDownloading(false);
             return;                 // skip this download
         }
     }
     else if (!output.open(QIODevice::WriteOnly)) {
 //        qDebug() << "No write permissions";
         emit statusChanged("failed");
-        downloading = false;
+        setIsDownloading(false);
         return;                 // skip this download
     }
 
@@ -150,7 +150,7 @@ void DownloadManager::downloadFinished() {
     }
     else {
         output.close();
-        downloading = false;
+        setIsDownloading(false);
         QString status;
         if (downloadReply->error()) {
             if (downloadReply->error() == QNetworkReply::OperationCanceledError) {
