@@ -5,12 +5,12 @@
     <name>AboutDialog</name>
     <message>
         <location filename="../AboutDialog.qml" line="44"/>
-        <source>cuteTube-QML - 0.7.1</source>
+        <source>cuteTube-QML - 0.7.5</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
-        <source>A feature-rich YouTube client for the Nokia N900. This is an experimental release using QML. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</source>
+        <source>A feature-rich YouTube client enabling browsing, playback and download of videos, plus account management. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</source>
         <translation></translation>
     </message>
 </context>
@@ -95,15 +95,15 @@
 <context>
     <name>ArchiveListView</name>
     <message>
-        <location filename="../ArchiveListView.qml" line="27"/>
+        <location filename="../ArchiveListView.qml" line="33"/>
         <source>Deleted from archive</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../ArchiveListView.qml" line="30"/>
-        <location filename="../ArchiveListView.qml" line="47"/>
+        <location filename="../ArchiveListView.qml" line="36"/>
+        <location filename="../ArchiveListView.qml" line="53"/>
         <source>Unable to delete from archive</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
 </context>
 <context>
@@ -163,22 +163,22 @@
 <context>
     <name>Controller</name>
     <message>
-        <location filename="../../../controller.cpp" line="188"/>
+        <location filename="../../../controller.cpp" line="222"/>
         <source>Video deleted from device</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="191"/>
+        <location filename="../../../controller.cpp" line="225"/>
         <source>Unable to delete video</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="195"/>
+        <location filename="../../../controller.cpp" line="229"/>
         <source>Video not found</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="250"/>
+        <location filename="../../../controller.cpp" line="284"/>
         <source>Copied to clipboard</source>
         <translation></translation>
     </message>
@@ -214,6 +214,14 @@
         <translation></translation>
     </message>
 </context>
+<context>
+    <name>MenuBar</name>
+    <message>
+        <location filename="../MenuBar.qml" line="130"/>
+        <source>Sort</source>
+        <translation></translation>
+    </message>
+</context>
 <context>
     <name>MyAccountView</name>
     <message>
@@ -301,12 +309,12 @@
 <context>
     <name>NotificationArea</name>
     <message>
-        <location filename="../NotificationArea.qml" line="50"/>
+        <location filename="../NotificationArea.qml" line="51"/>
         <source>No active downloads</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../NotificationArea.qml" line="145"/>
+        <location filename="../NotificationArea.qml" line="146"/>
         <source>Downloads</source>
         <translation></translation>
     </message>
@@ -342,7 +350,7 @@
     <message>
         <location filename="../PlaylistVideosView.qml" line="59"/>
         <source>Video(s) deleted from playlist</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../PlaylistVideosView.qml" line="80"/>
@@ -368,17 +376,17 @@
     <message>
         <location filename="../ProxyDialog.qml" line="30"/>
         <source>Network Proxy</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../ProxyDialog.qml" line="44"/>
         <source>Host (e.g. 192.168.100.1)</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../ProxyDialog.qml" line="51"/>
         <source>Port (e.g. 8080)</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
 </context>
 <context>
@@ -412,54 +420,64 @@
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../SettingsDialog.qml" line="192"/>
+        <location filename="../SettingsDialog.qml" line="195"/>
         <source>Your saved searches have been cleared</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="195"/>
+        <location filename="../SettingsDialog.qml" line="198"/>
         <source>Database error. Unable to clear searches</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="242"/>
+        <location filename="../SettingsDialog.qml" line="245"/>
         <source>Settings</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="283"/>
+        <location filename="../SettingsDialog.qml" line="311"/>
         <source>Playback quality</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="291"/>
+        <location filename="../SettingsDialog.qml" line="320"/>
         <source>Download quality</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="299"/>
+        <location filename="../SettingsDialog.qml" line="286"/>
         <source>Start downloads</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="307"/>
+        <location filename="../SettingsDialog.qml" line="354"/>
+        <source>Appearance</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="379"/>
+        <source>System</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="387"/>
         <source>Download location</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="323"/>
+        <location filename="../SettingsDialog.qml" line="396"/>
         <source>Screen orientation</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="331"/>
+        <location filename="../SettingsDialog.qml" line="302"/>
         <source>Media player</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="168"/>
-        <location filename="../SettingsDialog.qml" line="348"/>
-        <location filename="../SettingsDialog.qml" line="540"/>
+        <location filename="../SettingsDialog.qml" line="171"/>
+        <location filename="../SettingsDialog.qml" line="371"/>
+        <location filename="../SettingsDialog.qml" line="373"/>
         <source>Language</source>
         <translation></translation>
     </message>
@@ -467,76 +485,76 @@
         <location filename="../SettingsDialog.qml" line="37"/>
         <location filename="../SettingsDialog.qml" line="38"/>
         <source>High quality</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="43"/>
+        <location filename="../SettingsDialog.qml" line="44"/>
         <source>Russian</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="44"/>
+        <location filename="../SettingsDialog.qml" line="45"/>
         <source>Most recent</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="44"/>
+        <location filename="../SettingsDialog.qml" line="45"/>
         <source>Most viewed</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="45"/>
+        <location filename="../SettingsDialog.qml" line="46"/>
         <source>Archive</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="45"/>
+        <location filename="../SettingsDialog.qml" line="46"/>
         <source>Latest subscription videos</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="46"/>
+        <location filename="../SettingsDialog.qml" line="47"/>
         <source>My uploads</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="46"/>
+        <location filename="../SettingsDialog.qml" line="47"/>
         <source>My favourites</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="120"/>
-        <location filename="../SettingsDialog.qml" line="171"/>
+        <location filename="../SettingsDialog.qml" line="123"/>
+        <location filename="../SettingsDialog.qml" line="174"/>
         <source>Network Proxy</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../SettingsDialog.qml" line="144"/>
-        <location filename="../SettingsDialog.qml" line="394"/>
-        <source>Playback Quality</source>
         <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="147"/>
-        <location filename="../SettingsDialog.qml" line="412"/>
-        <source>Download Quality</source>
+        <location filename="../SettingsDialog.qml" line="313"/>
+        <source>Playback Quality</source>
         <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="150"/>
-        <location filename="../SettingsDialog.qml" line="430"/>
+        <location filename="../SettingsDialog.qml" line="322"/>
+        <source>Download Quality</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="153"/>
+        <location filename="../SettingsDialog.qml" line="288"/>
         <source>Start Downloads</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="159"/>
-        <location filename="../SettingsDialog.qml" line="486"/>
+        <location filename="../SettingsDialog.qml" line="162"/>
+        <location filename="../SettingsDialog.qml" line="398"/>
         <source>Screen Orientation</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="162"/>
-        <location filename="../SettingsDialog.qml" line="504"/>
+        <location filename="../SettingsDialog.qml" line="165"/>
+        <location filename="../SettingsDialog.qml" line="304"/>
         <source>Media Player</source>
         <translation></translation>
     </message>
@@ -549,17 +567,17 @@
     <message>
         <location filename="../SettingsDialog.qml" line="38"/>
         <source>360p</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="38"/>
         <source>480p</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="38"/>
         <source>720p</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="39"/>
@@ -574,12 +592,12 @@
     <message>
         <location filename="../SettingsDialog.qml" line="40"/>
         <source>On</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="40"/>
         <source>Off</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="41"/>
@@ -629,103 +647,128 @@
     <message>
         <location filename="../SettingsDialog.qml" line="43"/>
         <source>Dutch</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="43"/>
+        <location filename="../SettingsDialog.qml" line="44"/>
         <source>Polish</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="44"/>
+        <source>Portuguese</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="105"/>
+        <location filename="../SettingsDialog.qml" line="108"/>
         <source>Your settings have been saved</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="110"/>
-        <location filename="../SettingsDialog.qml" line="153"/>
+        <location filename="../SettingsDialog.qml" line="113"/>
+        <location filename="../SettingsDialog.qml" line="156"/>
         <source>Download Path</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="112"/>
+        <location filename="../SettingsDialog.qml" line="115"/>
         <source>Download Location</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="156"/>
-        <location filename="../SettingsDialog.qml" line="468"/>
+        <location filename="../SettingsDialog.qml" line="159"/>
+        <location filename="../SettingsDialog.qml" line="338"/>
         <source>Safe Search</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="165"/>
-        <location filename="../SettingsDialog.qml" line="339"/>
-        <location filename="../SettingsDialog.qml" line="522"/>
+        <location filename="../SettingsDialog.qml" line="168"/>
+        <location filename="../SettingsDialog.qml" line="362"/>
+        <location filename="../SettingsDialog.qml" line="364"/>
         <source>Theme</source>
         <translation></translation>
     </message>
-    <message>
-        <location filename="../SettingsDialog.qml" line="174"/>
-        <location filename="../SettingsDialog.qml" line="623"/>
-        <source>Widget Feed One</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../SettingsDialog.qml" line="177"/>
-        <location filename="../SettingsDialog.qml" line="643"/>
-        <source>Widget Feed Two</source>
-        <translation type="unfinished"></translation>
+        <location filename="../SettingsDialog.qml" line="422"/>
+        <source>Widget Feed One</source>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="180"/>
-        <location filename="../SettingsDialog.qml" line="663"/>
-        <source>Widget Feed Three</source>
-        <translation type="unfinished"></translation>
+        <location filename="../SettingsDialog.qml" line="431"/>
+        <source>Widget Feed Two</source>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="183"/>
-        <location filename="../SettingsDialog.qml" line="683"/>
+        <location filename="../SettingsDialog.qml" line="440"/>
+        <source>Widget Feed Three</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="186"/>
+        <location filename="../SettingsDialog.qml" line="449"/>
         <source>Widget Feed Four</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="275"/>
+        <location filename="../SettingsDialog.qml" line="269"/>
+        <source>Network</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="277"/>
         <source>Network proxy</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="315"/>
+        <location filename="../SettingsDialog.qml" line="294"/>
+        <source>Media</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="328"/>
+        <source>YouTube searches</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="336"/>
         <source>Safe search</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="367"/>
+        <location filename="../SettingsDialog.qml" line="412"/>
+        <source>Widget</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="420"/>
+        <source>Feed one</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="429"/>
+        <source>Feed two</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="438"/>
+        <source>Feed three</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="447"/>
+        <source>Feed four</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="278"/>
         <source>None</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="572"/>
-        <source>Feed One</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../SettingsDialog.qml" line="580"/>
-        <source>Feed Two</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../SettingsDialog.qml" line="588"/>
-        <source>Feed Three</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../SettingsDialog.qml" line="596"/>
-        <source>Feed Four</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../SettingsDialog.qml" line="698"/>
+        <location filename="../SettingsDialog.qml" line="347"/>
         <source>Clear saved searches</source>
         <translation></translation>
     </message>
@@ -743,12 +786,12 @@
     <message>
         <location filename="../SubscriptionsView.qml" line="36"/>
         <source>Latest Subscriptions Videos</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SubscriptionsView.qml" line="45"/>
         <source>You have unsubscribed to this channel</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SubscriptionsView.qml" line="104"/>
@@ -836,7 +879,7 @@
     </message>
     <message>
         <location filename="../UploadDialog.qml" line="35"/>
-        <location filename="../UploadDialog.qml" line="215"/>
+        <location filename="../UploadDialog.qml" line="216"/>
         <source>Category</source>
         <translation></translation>
     </message>
@@ -846,33 +889,33 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="138"/>
+        <location filename="../UploadDialog.qml" line="139"/>
         <source>File</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="147"/>
-        <location filename="../UploadDialog.qml" line="223"/>
+        <location filename="../UploadDialog.qml" line="148"/>
+        <location filename="../UploadDialog.qml" line="224"/>
         <source>None chosen</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="163"/>
+        <location filename="../UploadDialog.qml" line="164"/>
         <source>Title</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="176"/>
+        <location filename="../UploadDialog.qml" line="177"/>
         <source>Description (optional)</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="188"/>
+        <location filename="../UploadDialog.qml" line="189"/>
         <source>Tags (seperated by commas)</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="201"/>
+        <location filename="../UploadDialog.qml" line="202"/>
         <source>Private?</source>
         <translation></translation>
     </message>
@@ -993,7 +1036,7 @@
     <message>
         <location filename="../VideoInfoView.qml" line="443"/>
         <location filename="../VideoInfoView.qml" line="467"/>
-        <location filename="../VideoInfoView.qml" line="579"/>
+        <location filename="../VideoInfoView.qml" line="580"/>
         <source>You are not signed in to a YouTube account</source>
         <translation></translation>
     </message>
@@ -1022,7 +1065,7 @@
         <location filename="../VideoInfoView.qml" line="415"/>
         <location filename="../VideoInfoView.qml" line="418"/>
         <source> on </source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../VideoInfoView.qml" line="484"/>
@@ -1042,20 +1085,20 @@
     <message>
         <location filename="../VideoInfoView.qml" line="524"/>
         <source>No tags</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="591"/>
+        <location filename="../VideoInfoView.qml" line="592"/>
         <source>No comments</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="591"/>
+        <location filename="../VideoInfoView.qml" line="592"/>
         <source> comments</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="684"/>
+        <location filename="../VideoInfoView.qml" line="685"/>
         <source>No related videos</source>
         <translation></translation>
     </message>
@@ -1083,7 +1126,7 @@
     <message>
         <location filename="../VideoListView.qml" line="70"/>
         <source>Video(s) deleted from favourites</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../VideoListView.qml" line="92"/>
@@ -1144,97 +1187,82 @@
 <context>
     <name>main</name>
     <message>
-        <location filename="../main.qml" line="111"/>
+        <location filename="../main.qml" line="112"/>
         <source>Video(s) added to download queue</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="122"/>
+        <location filename="../main.qml" line="115"/>
+        <source>Video(s) already in download queue</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="126"/>
         <source>Audio track(s) added to download queue</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="153"/>
+        <location filename="../main.qml" line="129"/>
+        <source>Audio track(s) already in download queue</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="160"/>
         <source>Video added to favourites</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="154"/>
+        <location filename="../main.qml" line="161"/>
         <source>Video added to playlist</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="162"/>
+        <location filename="../main.qml" line="169"/>
         <source>New playlist created</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="207"/>
-        <source>Audio</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="212"/>
+        <location filename="../main.qml" line="219"/>
         <source>Conversion of &apos;</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="212"/>
+        <location filename="../main.qml" line="219"/>
         <source>&apos; failed</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="228"/>
-        <source>High quality</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="228"/>
-        <source>Mobile</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="228"/>
-        <source>360p</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="228"/>
-        <source>480p</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="228"/>
-        <source>720p</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="229"/>
+        <location filename="../main.qml" line="234"/>
         <source>Queued</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="229"/>
+        <location filename="../main.qml" line="234"/>
         <source>Paused</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="229"/>
+        <location filename="../main.qml" line="234"/>
         <source>Downloading</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="229"/>
+        <location filename="../main.qml" line="234"/>
         <source>Failed</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="234"/>
+        <source>Converting</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="396"/>
+        <location filename="../main.qml" line="416"/>
         <source>Most Recent</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="397"/>
+        <location filename="../main.qml" line="417"/>
         <source>Most Viewed</source>
         <translation></translation>
     </message>
@@ -1242,37 +1270,37 @@
 <context>
     <name>mainscripts</name>
     <message>
-        <location filename="../scripts/mainscripts.js" line="143"/>
+        <location filename="../scripts/mainscripts.js" line="152"/>
         <source>My Channel</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="158"/>
+        <location filename="../scripts/mainscripts.js" line="167"/>
         <source>Archive</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="197"/>
+        <location filename="../scripts/mainscripts.js" line="206"/>
         <source>My Playlists</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="207"/>
+        <location filename="../scripts/mainscripts.js" line="216"/>
         <source>My Subscriptions</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="220"/>
+        <location filename="../scripts/mainscripts.js" line="229"/>
         <source>Video Info</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="230"/>
+        <location filename="../scripts/mainscripts.js" line="239"/>
         <source>Video Playback</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="243"/>
+        <location filename="../scripts/mainscripts.js" line="252"/>
         <source>Search </source>
         <translation></translation>
     </message>
