@@ -52,9 +52,13 @@
         <translation type="obsolete">Ein funktionsreicher YouTube Client für das Nokia N900. Diese experimentelle Veröffentlichung basiert auf QML. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</translation>
     </message>
     <message>
-        <location filename="../AboutDialog.qml" line="44"/>
         <source>cuteTube-QML - 0.7.3</source>
-        <translation>cuteTube-QML - 0.7.3 in deutsch</translation>
+        <translation type="obsolete">cuteTube-QML - 0.7.3 in deutsch</translation>
+    </message>
+    <message>
+        <location filename="../AboutDialog.qml" line="44"/>
+        <source>cuteTube-QML - 0.7.5</source>
+        <translation>cuteTube-QML - 0.7.5 in deutsch</translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
@@ -275,22 +279,22 @@
         <translation type="obsolete">Polnisch</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="189"/>
+        <location filename="../../../controller.cpp" line="222"/>
         <source>Video deleted from device</source>
         <translation>Video vom Gerät gelöscht</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="192"/>
+        <location filename="../../../controller.cpp" line="225"/>
         <source>Unable to delete video</source>
         <translation>Löschen des Videos nicht möglich</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="196"/>
+        <location filename="../../../controller.cpp" line="229"/>
         <source>Video not found</source>
         <translation>Video nicht gefunden</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="251"/>
+        <location filename="../../../controller.cpp" line="284"/>
         <source>Copied to clipboard</source>
         <translation>In Zwischenablage kopiert</translation>
     </message>
@@ -491,12 +495,12 @@
 <context>
     <name>NotificationArea</name>
     <message>
-        <location filename="../NotificationArea.qml" line="50"/>
+        <location filename="../NotificationArea.qml" line="51"/>
         <source>No active downloads</source>
         <translation>Keine aktiven Downloads</translation>
     </message>
     <message>
-        <location filename="../NotificationArea.qml" line="145"/>
+        <location filename="../NotificationArea.qml" line="146"/>
         <source>Downloads</source>
         <translation>Downloads</translation>
     </message>
@@ -586,7 +590,7 @@
     <message>
         <location filename="../ProxyDialog.qml" line="30"/>
         <source>Network Proxy</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Netzwerk Proxy</translation>
     </message>
     <message>
         <location filename="../ProxyDialog.qml" line="44"/>
@@ -630,64 +634,64 @@
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../SettingsDialog.qml" line="194"/>
+        <location filename="../SettingsDialog.qml" line="195"/>
         <source>Your saved searches have been cleared</source>
         <translation>Die gespeicherten Suchen wurden gelöscht</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="197"/>
+        <location filename="../SettingsDialog.qml" line="198"/>
         <source>Database error. Unable to clear searches</source>
         <translation>Datenbankfehler. Konnte Konto nicht speichern</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="244"/>
+        <location filename="../SettingsDialog.qml" line="245"/>
         <source>Settings</source>
         <translation>Optionen</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="310"/>
+        <location filename="../SettingsDialog.qml" line="311"/>
         <source>Playback quality</source>
         <translation>Wiedergabequalität</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="319"/>
+        <location filename="../SettingsDialog.qml" line="320"/>
         <source>Download quality</source>
         <translation>Downloadqualität</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="285"/>
+        <location filename="../SettingsDialog.qml" line="286"/>
         <source>Start downloads</source>
         <translation>Downloads starten</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="353"/>
+        <location filename="../SettingsDialog.qml" line="354"/>
         <source>Appearance</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="378"/>
+        <location filename="../SettingsDialog.qml" line="379"/>
         <source>System</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="386"/>
+        <location filename="../SettingsDialog.qml" line="387"/>
         <source>Download location</source>
         <translation>Downloadverzeichnis</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="395"/>
+        <location filename="../SettingsDialog.qml" line="396"/>
         <source>Screen orientation</source>
         <translation>Bildschirmausrichtung</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="301"/>
+        <location filename="../SettingsDialog.qml" line="302"/>
         <source>Media player</source>
         <translation>Media Player</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="170"/>
-        <location filename="../SettingsDialog.qml" line="370"/>
-        <location filename="../SettingsDialog.qml" line="372"/>
+        <location filename="../SettingsDialog.qml" line="171"/>
+        <location filename="../SettingsDialog.qml" line="371"/>
+        <location filename="../SettingsDialog.qml" line="373"/>
         <source>Language</source>
         <translation>Sprache</translation>
     </message>
@@ -713,98 +717,103 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="43"/>
+        <location filename="../SettingsDialog.qml" line="44"/>
         <source>Russian</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="44"/>
+        <source>Portuguese</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="45"/>
         <source>Most recent</source>
         <translation>Aktuellste videos</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="44"/>
+        <location filename="../SettingsDialog.qml" line="45"/>
         <source>Most viewed</source>
         <translation>Meistgesehen</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="45"/>
+        <location filename="../SettingsDialog.qml" line="46"/>
         <source>Archive</source>
         <translation>Archiv</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="45"/>
+        <location filename="../SettingsDialog.qml" line="46"/>
         <source>Latest subscription videos</source>
         <translation>Letzte abonnierte videos</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="46"/>
+        <location filename="../SettingsDialog.qml" line="47"/>
         <source>My uploads</source>
         <translation>Mein uploads</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="46"/>
+        <location filename="../SettingsDialog.qml" line="47"/>
         <source>My favourites</source>
         <translation>Mein favoriten</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="122"/>
-        <location filename="../SettingsDialog.qml" line="173"/>
+        <location filename="../SettingsDialog.qml" line="123"/>
+        <location filename="../SettingsDialog.qml" line="174"/>
         <source>Network Proxy</source>
         <translation>Netzwerk Proxy</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="146"/>
-        <location filename="../SettingsDialog.qml" line="312"/>
+        <location filename="../SettingsDialog.qml" line="147"/>
+        <location filename="../SettingsDialog.qml" line="313"/>
         <source>Playback Quality</source>
         <translation>Wiedergabequalität</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="149"/>
-        <location filename="../SettingsDialog.qml" line="321"/>
+        <location filename="../SettingsDialog.qml" line="150"/>
+        <location filename="../SettingsDialog.qml" line="322"/>
         <source>Download Quality</source>
         <translation>Downloadqualität</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="152"/>
-        <location filename="../SettingsDialog.qml" line="287"/>
+        <location filename="../SettingsDialog.qml" line="153"/>
+        <location filename="../SettingsDialog.qml" line="288"/>
         <source>Start Downloads</source>
         <translation>Downloads starten</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="161"/>
-        <location filename="../SettingsDialog.qml" line="397"/>
+        <location filename="../SettingsDialog.qml" line="162"/>
+        <location filename="../SettingsDialog.qml" line="398"/>
         <source>Screen Orientation</source>
         <translation>Bildschirmausrichtung</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="164"/>
-        <location filename="../SettingsDialog.qml" line="303"/>
+        <location filename="../SettingsDialog.qml" line="165"/>
+        <location filename="../SettingsDialog.qml" line="304"/>
         <source>Media Player</source>
         <translation>Media Player</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="411"/>
+        <location filename="../SettingsDialog.qml" line="412"/>
         <source>Widget</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="419"/>
+        <location filename="../SettingsDialog.qml" line="420"/>
         <source>Feed one</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="428"/>
+        <location filename="../SettingsDialog.qml" line="429"/>
         <source>Feed two</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="437"/>
+        <location filename="../SettingsDialog.qml" line="438"/>
         <source>Feed three</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="446"/>
+        <location filename="../SettingsDialog.qml" line="447"/>
         <source>Feed four</source>
         <translation type="unfinished"></translation>
     </message>
@@ -889,7 +898,7 @@
         <translation>Niederländisch</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="43"/>
+        <location filename="../SettingsDialog.qml" line="44"/>
         <source>Polish</source>
         <translation>Polnisch</translation>
     </message>
@@ -902,90 +911,90 @@
         <translation type="obsolete">Pausiert</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="107"/>
+        <location filename="../SettingsDialog.qml" line="108"/>
         <source>Your settings have been saved</source>
         <translation>Ihre Einstellungen wurden gespeichert</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="112"/>
-        <location filename="../SettingsDialog.qml" line="155"/>
+        <location filename="../SettingsDialog.qml" line="113"/>
+        <location filename="../SettingsDialog.qml" line="156"/>
         <source>Download Path</source>
         <translation>Downloadverzeichnis</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="114"/>
+        <location filename="../SettingsDialog.qml" line="115"/>
         <source>Download Location</source>
         <translation>Downloadverzeichnis</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="158"/>
-        <location filename="../SettingsDialog.qml" line="337"/>
+        <location filename="../SettingsDialog.qml" line="159"/>
+        <location filename="../SettingsDialog.qml" line="338"/>
         <source>Safe Search</source>
         <translation>Sicherer Modus</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="167"/>
-        <location filename="../SettingsDialog.qml" line="361"/>
-        <location filename="../SettingsDialog.qml" line="363"/>
+        <location filename="../SettingsDialog.qml" line="168"/>
+        <location filename="../SettingsDialog.qml" line="362"/>
+        <location filename="../SettingsDialog.qml" line="364"/>
         <source>Theme</source>
         <translation>Thema</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="176"/>
-        <location filename="../SettingsDialog.qml" line="421"/>
+        <location filename="../SettingsDialog.qml" line="177"/>
+        <location filename="../SettingsDialog.qml" line="422"/>
         <source>Widget Feed One</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="179"/>
-        <location filename="../SettingsDialog.qml" line="430"/>
+        <location filename="../SettingsDialog.qml" line="180"/>
+        <location filename="../SettingsDialog.qml" line="431"/>
         <source>Widget Feed Two</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="182"/>
-        <location filename="../SettingsDialog.qml" line="439"/>
+        <location filename="../SettingsDialog.qml" line="183"/>
+        <location filename="../SettingsDialog.qml" line="440"/>
         <source>Widget Feed Three</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="185"/>
-        <location filename="../SettingsDialog.qml" line="448"/>
+        <location filename="../SettingsDialog.qml" line="186"/>
+        <location filename="../SettingsDialog.qml" line="449"/>
         <source>Widget Feed Four</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="268"/>
+        <location filename="../SettingsDialog.qml" line="269"/>
         <source>Network</source>
         <translation>Netzwerk</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="276"/>
+        <location filename="../SettingsDialog.qml" line="277"/>
         <source>Network proxy</source>
         <translation>Netzwerk proxy</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="293"/>
+        <location filename="../SettingsDialog.qml" line="294"/>
         <source>Media</source>
         <translation>Medien</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="327"/>
+        <location filename="../SettingsDialog.qml" line="328"/>
         <source>YouTube searches</source>
         <translation>YouTube suche</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="335"/>
+        <location filename="../SettingsDialog.qml" line="336"/>
         <source>Safe search</source>
         <translation>Sicher suchlauf</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="277"/>
+        <location filename="../SettingsDialog.qml" line="278"/>
         <source>None</source>
         <translation>Kein proxy</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="346"/>
+        <location filename="../SettingsDialog.qml" line="347"/>
         <source>Clear saved searches</source>
         <translation>Lösche Suche</translation>
     </message>
@@ -1309,7 +1318,7 @@
     <message>
         <location filename="../VideoInfoView.qml" line="443"/>
         <location filename="../VideoInfoView.qml" line="467"/>
-        <location filename="../VideoInfoView.qml" line="579"/>
+        <location filename="../VideoInfoView.qml" line="580"/>
         <source>You are not signed in to a YouTube account</source>
         <translation>Nicht bei einem YouTube Konto angemeldet</translation>
     </message>
@@ -1361,17 +1370,17 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="591"/>
+        <location filename="../VideoInfoView.qml" line="592"/>
         <source>No comments</source>
         <translation>Keine Kommentare</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="591"/>
+        <location filename="../VideoInfoView.qml" line="592"/>
         <source> comments</source>
         <translation>Kommentare</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="684"/>
+        <location filename="../VideoInfoView.qml" line="685"/>
         <source>No related videos</source>
         <translation>Keine ähnlichen Videos</translation>
     </message>
@@ -1590,41 +1599,52 @@
         <translation type="obsolete">Hell</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="111"/>
+        <location filename="../main.qml" line="112"/>
         <source>Video(s) added to download queue</source>
         <translation>Video(s) in Warteschlange eingefügt</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="122"/>
+        <location filename="../main.qml" line="115"/>
+        <source>Video(s) already in download queue</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="126"/>
         <source>Audio track(s) added to download queue</source>
         <translation>Audio Tracks in Warteschlange eingefügt</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="153"/>
+        <location filename="../main.qml" line="129"/>
+        <source>Audio track(s) already in download queue</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="160"/>
         <source>Video added to favourites</source>
         <translation>Video wurde zu Favoriten hinzugefügt</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="154"/>
+        <location filename="../main.qml" line="161"/>
         <source>Video added to playlist</source>
         <translation>Video wurde zur Wiedergabeliste hinzugefügt</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="162"/>
+        <location filename="../main.qml" line="169"/>
         <source>New playlist created</source>
         <translation>Neue Wiedergabeliste erstellt</translation>
     </message>
     <message>
+        <location filename="../main.qml" line="234"/>
         <source>Converting</source>
-        <translation type="obsolete">Konvertiere</translation>
+        <translation>Konvertiere</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="212"/>
+        <location filename="../main.qml" line="219"/>
         <source>Conversion of &apos;</source>
         <translation>Unterhaltung zwischen &apos;</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="212"/>
+        <location filename="../main.qml" line="219"/>
         <source>&apos; failed</source>
         <translation>&apos; gescheitert</translation>
     </message>
@@ -1637,32 +1657,32 @@
         <translation type="obsolete">Mobil</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="234"/>
         <source>Queued</source>
         <translation>in Warteschlange</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="234"/>
         <source>Paused</source>
         <translation>Pausiert</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="234"/>
         <source>Downloading</source>
         <translation>am Herrunterladen</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="234"/>
         <source>Failed</source>
         <translation>Fehlgeschlagen</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="396"/>
+        <location filename="../main.qml" line="416"/>
         <source>Most Recent</source>
         <translation>Aktuellste Videos</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="397"/>
+        <location filename="../main.qml" line="417"/>
         <source>Most Viewed</source>
         <translation>Meistgesehen</translation>
     </message>
@@ -1674,32 +1694,32 @@
         <translation type="obsolete">Media Player</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="146"/>
+        <location filename="../scripts/mainscripts.js" line="152"/>
         <source>My Channel</source>
         <translation>Mein Kanal</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="161"/>
+        <location filename="../scripts/mainscripts.js" line="167"/>
         <source>Archive</source>
         <translation>Archiv</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="200"/>
+        <location filename="../scripts/mainscripts.js" line="206"/>
         <source>My Playlists</source>
         <translation>Mein Wiedergabelisten</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="210"/>
+        <location filename="../scripts/mainscripts.js" line="216"/>
         <source>My Subscriptions</source>
         <translation>Mein Abonnement</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="223"/>
+        <location filename="../scripts/mainscripts.js" line="229"/>
         <source>Video Info</source>
         <translation>Video Info</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="233"/>
+        <location filename="../scripts/mainscripts.js" line="239"/>
         <source>Video Playback</source>
         <translation>Video abspielen</translation>
     </message>
@@ -1724,7 +1744,7 @@
         <translation type="obsolete">bewertung</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="246"/>
+        <location filename="../scripts/mainscripts.js" line="252"/>
         <source>Search </source>
         <translation>Suchlauf</translation>
     </message>
