@@ -32,9 +32,13 @@
         <translation type="obsolete">Monipuolinen YouTube -clientti Nokia N900:lle. Tämä on QML käyttävä kehitysversio. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</translation>
     </message>
     <message>
-        <location filename="../AboutDialog.qml" line="44"/>
         <source>cuteTube-QML - 0.7.3</source>
-        <translation type="unfinished">cuteTube-QML - 0.7.3 - Suomennos: d-iivil</translation>
+        <translation type="obsolete">cuteTube-QML - 0.7.3 - Suomennos: d-iivil</translation>
+    </message>
+    <message>
+        <location filename="../AboutDialog.qml" line="44"/>
+        <source>cuteTube-QML - 0.7.5</source>
+        <translation type="unfinished">cuteTube-QML - 0.7.5 - Suomennos: d-iivil</translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
@@ -223,22 +227,22 @@
         <translation type="obsolete">Puolalainen</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="189"/>
+        <location filename="../../../controller.cpp" line="222"/>
         <source>Video deleted from device</source>
         <translation>Video poistettu laitteesta</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="192"/>
+        <location filename="../../../controller.cpp" line="225"/>
         <source>Unable to delete video</source>
         <translation>Videon poisto epäonnistui</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="196"/>
+        <location filename="../../../controller.cpp" line="229"/>
         <source>Video not found</source>
         <translation>Videota ei löytynyt</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="251"/>
+        <location filename="../../../controller.cpp" line="284"/>
         <source>Copied to clipboard</source>
         <translation>Kopioitu leikepöydälle</translation>
     </message>
@@ -431,12 +435,12 @@
 <context>
     <name>NotificationArea</name>
     <message>
-        <location filename="../NotificationArea.qml" line="50"/>
+        <location filename="../NotificationArea.qml" line="51"/>
         <source>No active downloads</source>
         <translation>Ei aktiivisia latauksia</translation>
     </message>
     <message>
-        <location filename="../NotificationArea.qml" line="145"/>
+        <location filename="../NotificationArea.qml" line="146"/>
         <source>Downloads</source>
         <translation>Lataukset</translation>
     </message>
@@ -615,43 +619,48 @@
         <translation>Pysty</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="43"/>
+        <location filename="../SettingsDialog.qml" line="44"/>
         <source>Russian</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="44"/>
+        <source>Portuguese</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="45"/>
         <source>Most recent</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="44"/>
+        <location filename="../SettingsDialog.qml" line="45"/>
         <source>Most viewed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="45"/>
+        <location filename="../SettingsDialog.qml" line="46"/>
         <source>Archive</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="45"/>
+        <location filename="../SettingsDialog.qml" line="46"/>
         <source>Latest subscription videos</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="46"/>
+        <location filename="../SettingsDialog.qml" line="47"/>
         <source>My uploads</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="46"/>
+        <location filename="../SettingsDialog.qml" line="47"/>
         <source>My favourites</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="164"/>
-        <location filename="../SettingsDialog.qml" line="303"/>
+        <location filename="../SettingsDialog.qml" line="165"/>
+        <location filename="../SettingsDialog.qml" line="304"/>
         <source>Media Player</source>
         <translation>Mediasoitin</translation>
     </message>
@@ -712,7 +721,7 @@
         <translation>Alankomaiden</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="43"/>
+        <location filename="../SettingsDialog.qml" line="44"/>
         <source>Polish</source>
         <translation>Puolalainen</translation>
     </message>
@@ -725,207 +734,207 @@
         <translation type="obsolete">Pysäytetty</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="107"/>
+        <location filename="../SettingsDialog.qml" line="108"/>
         <source>Your settings have been saved</source>
         <translation>Asetukset tallennettu</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="112"/>
-        <location filename="../SettingsDialog.qml" line="155"/>
+        <location filename="../SettingsDialog.qml" line="113"/>
+        <location filename="../SettingsDialog.qml" line="156"/>
         <source>Download Path</source>
         <translation>Latauspolku</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="114"/>
+        <location filename="../SettingsDialog.qml" line="115"/>
         <source>Download Location</source>
         <translation>Lataussijainti</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="122"/>
-        <location filename="../SettingsDialog.qml" line="173"/>
+        <location filename="../SettingsDialog.qml" line="123"/>
+        <location filename="../SettingsDialog.qml" line="174"/>
         <source>Network Proxy</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="146"/>
-        <location filename="../SettingsDialog.qml" line="312"/>
+        <location filename="../SettingsDialog.qml" line="147"/>
+        <location filename="../SettingsDialog.qml" line="313"/>
         <source>Playback Quality</source>
         <translation>Toistolaatu</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="149"/>
-        <location filename="../SettingsDialog.qml" line="321"/>
+        <location filename="../SettingsDialog.qml" line="150"/>
+        <location filename="../SettingsDialog.qml" line="322"/>
         <source>Download Quality</source>
         <translation>Latauksen laatu</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="152"/>
-        <location filename="../SettingsDialog.qml" line="287"/>
+        <location filename="../SettingsDialog.qml" line="153"/>
+        <location filename="../SettingsDialog.qml" line="288"/>
         <source>Start Downloads</source>
         <translation>Käynnistä lataukset</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="158"/>
-        <location filename="../SettingsDialog.qml" line="337"/>
+        <location filename="../SettingsDialog.qml" line="159"/>
+        <location filename="../SettingsDialog.qml" line="338"/>
         <source>Safe Search</source>
         <translation>Turvallinen Haku</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="161"/>
-        <location filename="../SettingsDialog.qml" line="397"/>
+        <location filename="../SettingsDialog.qml" line="162"/>
+        <location filename="../SettingsDialog.qml" line="398"/>
         <source>Screen Orientation</source>
         <translation>Käyttöliittymän suunta</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="167"/>
-        <location filename="../SettingsDialog.qml" line="361"/>
-        <location filename="../SettingsDialog.qml" line="363"/>
+        <location filename="../SettingsDialog.qml" line="168"/>
+        <location filename="../SettingsDialog.qml" line="362"/>
+        <location filename="../SettingsDialog.qml" line="364"/>
         <source>Theme</source>
         <translation>Teema</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="170"/>
-        <location filename="../SettingsDialog.qml" line="370"/>
-        <location filename="../SettingsDialog.qml" line="372"/>
+        <location filename="../SettingsDialog.qml" line="171"/>
+        <location filename="../SettingsDialog.qml" line="371"/>
+        <location filename="../SettingsDialog.qml" line="373"/>
         <source>Language</source>
         <translation>Kieli</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="176"/>
-        <location filename="../SettingsDialog.qml" line="421"/>
+        <location filename="../SettingsDialog.qml" line="177"/>
+        <location filename="../SettingsDialog.qml" line="422"/>
         <source>Widget Feed One</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="179"/>
-        <location filename="../SettingsDialog.qml" line="430"/>
+        <location filename="../SettingsDialog.qml" line="180"/>
+        <location filename="../SettingsDialog.qml" line="431"/>
         <source>Widget Feed Two</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="182"/>
-        <location filename="../SettingsDialog.qml" line="439"/>
+        <location filename="../SettingsDialog.qml" line="183"/>
+        <location filename="../SettingsDialog.qml" line="440"/>
         <source>Widget Feed Three</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="185"/>
-        <location filename="../SettingsDialog.qml" line="448"/>
+        <location filename="../SettingsDialog.qml" line="186"/>
+        <location filename="../SettingsDialog.qml" line="449"/>
         <source>Widget Feed Four</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="194"/>
+        <location filename="../SettingsDialog.qml" line="195"/>
         <source>Your saved searches have been cleared</source>
         <translation>Tallennetut hakusanat on tyhjennetty</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="197"/>
+        <location filename="../SettingsDialog.qml" line="198"/>
         <source>Database error. Unable to clear searches</source>
         <translation>Tietokantavirhe. Hakuja ei tyhjennetty</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="244"/>
+        <location filename="../SettingsDialog.qml" line="245"/>
         <source>Settings</source>
         <translation>Asetukset</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="268"/>
+        <location filename="../SettingsDialog.qml" line="269"/>
         <source>Network</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="276"/>
+        <location filename="../SettingsDialog.qml" line="277"/>
         <source>Network proxy</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="293"/>
+        <location filename="../SettingsDialog.qml" line="294"/>
         <source>Media</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="310"/>
+        <location filename="../SettingsDialog.qml" line="311"/>
         <source>Playback quality</source>
         <translation>Toistolaatu</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="319"/>
+        <location filename="../SettingsDialog.qml" line="320"/>
         <source>Download quality</source>
         <translation>Latauksien laatu</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="411"/>
+        <location filename="../SettingsDialog.qml" line="412"/>
         <source>Widget</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="419"/>
+        <location filename="../SettingsDialog.qml" line="420"/>
         <source>Feed one</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="428"/>
+        <location filename="../SettingsDialog.qml" line="429"/>
         <source>Feed two</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="437"/>
+        <location filename="../SettingsDialog.qml" line="438"/>
         <source>Feed three</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="446"/>
+        <location filename="../SettingsDialog.qml" line="447"/>
         <source>Feed four</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="285"/>
+        <location filename="../SettingsDialog.qml" line="286"/>
         <source>Start downloads</source>
         <translation>Aloita lataukset</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="327"/>
+        <location filename="../SettingsDialog.qml" line="328"/>
         <source>YouTube searches</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="353"/>
+        <location filename="../SettingsDialog.qml" line="354"/>
         <source>Appearance</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="378"/>
+        <location filename="../SettingsDialog.qml" line="379"/>
         <source>System</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="386"/>
+        <location filename="../SettingsDialog.qml" line="387"/>
         <source>Download location</source>
         <translation>Latauskansio</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="335"/>
+        <location filename="../SettingsDialog.qml" line="336"/>
         <source>Safe search</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="395"/>
+        <location filename="../SettingsDialog.qml" line="396"/>
         <source>Screen orientation</source>
         <translation>Käyttöliittymän suunta</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="301"/>
+        <location filename="../SettingsDialog.qml" line="302"/>
         <source>Media player</source>
         <translation>Mediasoitin</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="277"/>
+        <location filename="../SettingsDialog.qml" line="278"/>
         <source>None</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="346"/>
+        <location filename="../SettingsDialog.qml" line="347"/>
         <source>Clear saved searches</source>
         <translation>Tyhjennä hakusanat</translation>
     </message>
@@ -1241,7 +1250,7 @@
     <message>
         <location filename="../VideoInfoView.qml" line="443"/>
         <location filename="../VideoInfoView.qml" line="467"/>
-        <location filename="../VideoInfoView.qml" line="579"/>
+        <location filename="../VideoInfoView.qml" line="580"/>
         <source>You are not signed in to a YouTube account</source>
         <translation>Et ole kirjautunut YouTubeen</translation>
     </message>
@@ -1293,17 +1302,17 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="591"/>
+        <location filename="../VideoInfoView.qml" line="592"/>
         <source>No comments</source>
         <translation>Ei kommentteja</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="591"/>
+        <location filename="../VideoInfoView.qml" line="592"/>
         <source> comments</source>
         <translation>kommentit</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="684"/>
+        <location filename="../VideoInfoView.qml" line="685"/>
         <source>No related videos</source>
         <translation>Ei liittyviä videoita</translation>
     </message>
@@ -1522,41 +1531,52 @@
         <translation type="obsolete">Vaalea</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="111"/>
+        <location filename="../main.qml" line="112"/>
         <source>Video(s) added to download queue</source>
         <translation>Video(t) lisätty latausjonoon</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="122"/>
+        <location filename="../main.qml" line="115"/>
+        <source>Video(s) already in download queue</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="126"/>
         <source>Audio track(s) added to download queue</source>
         <translation>Audio(t) lisätty latausjonoon</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="153"/>
+        <location filename="../main.qml" line="129"/>
+        <source>Audio track(s) already in download queue</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="160"/>
         <source>Video added to favourites</source>
         <translation>Video lisätty suosikkeihin</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="154"/>
+        <location filename="../main.qml" line="161"/>
         <source>Video added to playlist</source>
         <translation>Video lisätty soittolistalle</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="162"/>
+        <location filename="../main.qml" line="169"/>
         <source>New playlist created</source>
         <translation>Uusi soittolista luotu</translation>
     </message>
     <message>
+        <location filename="../main.qml" line="234"/>
         <source>Converting</source>
-        <translation type="obsolete">Muunnetaan</translation>
+        <translation>Muunnetaan</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="212"/>
+        <location filename="../main.qml" line="219"/>
         <source>Conversion of &apos;</source>
         <translation>Muunto: </translation>
     </message>
     <message>
-        <location filename="../main.qml" line="212"/>
+        <location filename="../main.qml" line="219"/>
         <source>&apos; failed</source>
         <translation> epäonnistui</translation>
     </message>
@@ -1565,32 +1585,32 @@
         <translation type="obsolete">Mobiili</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="234"/>
         <source>Queued</source>
         <translation>Jonossa</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="234"/>
         <source>Paused</source>
         <translation>Keskeytetty</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="234"/>
         <source>Downloading</source>
         <translation>Ladataan</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="234"/>
         <source>Failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="396"/>
+        <location filename="../main.qml" line="416"/>
         <source>Most Recent</source>
         <translation>Tuoreimmat</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="397"/>
+        <location filename="../main.qml" line="417"/>
         <source>Most Viewed</source>
         <translation>Katsotuimmat</translation>
     </message>
@@ -1602,32 +1622,32 @@
         <translation type="obsolete">Mediasoitin</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="146"/>
+        <location filename="../scripts/mainscripts.js" line="152"/>
         <source>My Channel</source>
         <translation>Oma kanavani</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="161"/>
+        <location filename="../scripts/mainscripts.js" line="167"/>
         <source>Archive</source>
         <translation>Arkisto</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="200"/>
+        <location filename="../scripts/mainscripts.js" line="206"/>
         <source>My Playlists</source>
         <translation>Omat soittolistani</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="210"/>
+        <location filename="../scripts/mainscripts.js" line="216"/>
         <source>My Subscriptions</source>
         <translation>Omat tilaukseni</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="223"/>
+        <location filename="../scripts/mainscripts.js" line="229"/>
         <source>Video Info</source>
         <translation>Videon tiedot</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="233"/>
+        <location filename="../scripts/mainscripts.js" line="239"/>
         <source>Video Playback</source>
         <translation>Videon toisto</translation>
     </message>
@@ -1652,7 +1672,7 @@
         <translation type="obsolete">arvio</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="246"/>
+        <location filename="../scripts/mainscripts.js" line="252"/>
         <source>Search </source>
         <translation>Haku</translation>
     </message>
