@@ -9,8 +9,8 @@
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="44"/>
-        <source>cuteTube-QML - 0.7.3</source>
-        <translation></translation>
+        <source>cuteTube-QML - 0.7.5</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
@@ -191,22 +191,22 @@
         <translation type="obsolete">Polacco</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="189"/>
+        <location filename="../../../controller.cpp" line="222"/>
         <source>Video deleted from device</source>
         <translation>Video cancellato dal dispositivo</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="192"/>
+        <location filename="../../../controller.cpp" line="225"/>
         <source>Unable to delete video</source>
         <translation>Impossibile cancellare il video</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="196"/>
+        <location filename="../../../controller.cpp" line="229"/>
         <source>Video not found</source>
         <translation>Video non trovato</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="251"/>
+        <location filename="../../../controller.cpp" line="284"/>
         <source>Copied to clipboard</source>
         <translation>Copiato negli appunti</translation>
     </message>
@@ -387,12 +387,12 @@
 <context>
     <name>NotificationArea</name>
     <message>
-        <location filename="../NotificationArea.qml" line="50"/>
+        <location filename="../NotificationArea.qml" line="51"/>
         <source>No active downloads</source>
         <translation>Nessun download attivo</translation>
     </message>
     <message>
-        <location filename="../NotificationArea.qml" line="145"/>
+        <location filename="../NotificationArea.qml" line="146"/>
         <source>Downloads</source>
         <translation></translation>
     </message>
@@ -567,43 +567,48 @@
         <translation>Verticale</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="43"/>
+        <location filename="../SettingsDialog.qml" line="44"/>
         <source>Russian</source>
         <translation>Russo</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="44"/>
+        <source>Portuguese</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="45"/>
         <source>Most recent</source>
         <translation>I più recenti</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="44"/>
+        <location filename="../SettingsDialog.qml" line="45"/>
         <source>Most viewed</source>
         <translation>I più visti</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="45"/>
+        <location filename="../SettingsDialog.qml" line="46"/>
         <source>Archive</source>
         <translation>Archivio</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="45"/>
+        <location filename="../SettingsDialog.qml" line="46"/>
         <source>Latest subscription videos</source>
         <translation>Novità da iscrizioni</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="46"/>
+        <location filename="../SettingsDialog.qml" line="47"/>
         <source>My uploads</source>
         <translation>I miei video</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="46"/>
+        <location filename="../SettingsDialog.qml" line="47"/>
         <source>My favourites</source>
         <translation>I miei preferiti</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="164"/>
-        <location filename="../SettingsDialog.qml" line="303"/>
+        <location filename="../SettingsDialog.qml" line="165"/>
+        <location filename="../SettingsDialog.qml" line="304"/>
         <source>Media Player</source>
         <translation></translation>
     </message>
@@ -664,7 +669,7 @@
         <translation>Olandese</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="43"/>
+        <location filename="../SettingsDialog.qml" line="44"/>
         <source>Polish</source>
         <translation>Polacco</translation>
     </message>
@@ -677,202 +682,202 @@
         <translation type="obsolete">In Pausa</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="107"/>
+        <location filename="../SettingsDialog.qml" line="108"/>
         <source>Your settings have been saved</source>
         <translation>Le tue impostazioni sono state salvate</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="112"/>
-        <location filename="../SettingsDialog.qml" line="155"/>
+        <location filename="../SettingsDialog.qml" line="113"/>
+        <location filename="../SettingsDialog.qml" line="156"/>
         <source>Download Path</source>
         <translation>Percorso Download</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="114"/>
+        <location filename="../SettingsDialog.qml" line="115"/>
         <source>Download Location</source>
         <translation>Destinazione Download</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="122"/>
-        <location filename="../SettingsDialog.qml" line="173"/>
+        <location filename="../SettingsDialog.qml" line="123"/>
+        <location filename="../SettingsDialog.qml" line="174"/>
         <source>Network Proxy</source>
         <translation>Rete Proxy</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="146"/>
-        <location filename="../SettingsDialog.qml" line="312"/>
+        <location filename="../SettingsDialog.qml" line="147"/>
+        <location filename="../SettingsDialog.qml" line="313"/>
         <source>Playback Quality</source>
         <translation>Qualità Riproduzione</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="149"/>
-        <location filename="../SettingsDialog.qml" line="321"/>
+        <location filename="../SettingsDialog.qml" line="150"/>
+        <location filename="../SettingsDialog.qml" line="322"/>
         <source>Download Quality</source>
         <translation>Qualità Download</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="152"/>
-        <location filename="../SettingsDialog.qml" line="287"/>
+        <location filename="../SettingsDialog.qml" line="153"/>
+        <location filename="../SettingsDialog.qml" line="288"/>
         <source>Start Downloads</source>
         <translation>Inizia Download</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="158"/>
-        <location filename="../SettingsDialog.qml" line="337"/>
+        <location filename="../SettingsDialog.qml" line="159"/>
+        <location filename="../SettingsDialog.qml" line="338"/>
         <source>Safe Search</source>
         <translation>Ricerca Sicura</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="161"/>
-        <location filename="../SettingsDialog.qml" line="397"/>
+        <location filename="../SettingsDialog.qml" line="162"/>
+        <location filename="../SettingsDialog.qml" line="398"/>
         <source>Screen Orientation</source>
         <translation>Orientamento Schermo</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="167"/>
-        <location filename="../SettingsDialog.qml" line="361"/>
-        <location filename="../SettingsDialog.qml" line="363"/>
+        <location filename="../SettingsDialog.qml" line="168"/>
+        <location filename="../SettingsDialog.qml" line="362"/>
+        <location filename="../SettingsDialog.qml" line="364"/>
         <source>Theme</source>
         <translation>Tema</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="170"/>
-        <location filename="../SettingsDialog.qml" line="370"/>
-        <location filename="../SettingsDialog.qml" line="372"/>
+        <location filename="../SettingsDialog.qml" line="171"/>
+        <location filename="../SettingsDialog.qml" line="371"/>
+        <location filename="../SettingsDialog.qml" line="373"/>
         <source>Language</source>
         <translation>Lingua</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="176"/>
-        <location filename="../SettingsDialog.qml" line="421"/>
+        <location filename="../SettingsDialog.qml" line="177"/>
+        <location filename="../SettingsDialog.qml" line="422"/>
         <source>Widget Feed One</source>
         <translation>Feed Widget Uno</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="179"/>
-        <location filename="../SettingsDialog.qml" line="430"/>
+        <location filename="../SettingsDialog.qml" line="180"/>
+        <location filename="../SettingsDialog.qml" line="431"/>
         <source>Widget Feed Two</source>
         <translation>Feed Widget Due</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="182"/>
-        <location filename="../SettingsDialog.qml" line="439"/>
+        <location filename="../SettingsDialog.qml" line="183"/>
+        <location filename="../SettingsDialog.qml" line="440"/>
         <source>Widget Feed Three</source>
         <translation>Feed Widget Tre</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="185"/>
-        <location filename="../SettingsDialog.qml" line="448"/>
+        <location filename="../SettingsDialog.qml" line="186"/>
+        <location filename="../SettingsDialog.qml" line="449"/>
         <source>Widget Feed Four</source>
         <translation>Feed Widget Quattro</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="194"/>
+        <location filename="../SettingsDialog.qml" line="195"/>
         <source>Your saved searches have been cleared</source>
         <translation>Le tue ricerche salvate sono state cancellate</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="197"/>
+        <location filename="../SettingsDialog.qml" line="198"/>
         <source>Database error. Unable to clear searches</source>
         <translation>Errore database. Impossibile cancellare le ricerche</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="244"/>
+        <location filename="../SettingsDialog.qml" line="245"/>
         <source>Settings</source>
         <translation>Impostazioni</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="268"/>
+        <location filename="../SettingsDialog.qml" line="269"/>
         <source>Network</source>
         <translation>Rete</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="276"/>
+        <location filename="../SettingsDialog.qml" line="277"/>
         <source>Network proxy</source>
         <translation>Rete proxy</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="293"/>
+        <location filename="../SettingsDialog.qml" line="294"/>
         <source>Media</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="310"/>
+        <location filename="../SettingsDialog.qml" line="311"/>
         <source>Playback quality</source>
         <translation>Qualità riproduzione</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="319"/>
+        <location filename="../SettingsDialog.qml" line="320"/>
         <source>Download quality</source>
         <translation>Qualità download</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="411"/>
+        <location filename="../SettingsDialog.qml" line="412"/>
         <source>Widget</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="419"/>
+        <location filename="../SettingsDialog.qml" line="420"/>
         <source>Feed one</source>
         <translation>Feed uno</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="428"/>
+        <location filename="../SettingsDialog.qml" line="429"/>
         <source>Feed two</source>
         <translation>Feed due</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="437"/>
+        <location filename="../SettingsDialog.qml" line="438"/>
         <source>Feed three</source>
         <translation>Feed tre</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="446"/>
+        <location filename="../SettingsDialog.qml" line="447"/>
         <source>Feed four</source>
         <translation>Feed quattro</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="285"/>
+        <location filename="../SettingsDialog.qml" line="286"/>
         <source>Start downloads</source>
         <translation>Inizia download</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="327"/>
+        <location filename="../SettingsDialog.qml" line="328"/>
         <source>YouTube searches</source>
         <translation>Ricerche YouTube</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="353"/>
+        <location filename="../SettingsDialog.qml" line="354"/>
         <source>Appearance</source>
         <translation>Aspetto</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="378"/>
+        <location filename="../SettingsDialog.qml" line="379"/>
         <source>System</source>
         <translation>Sistema</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="386"/>
+        <location filename="../SettingsDialog.qml" line="387"/>
         <source>Download location</source>
         <translation>Destinazione download</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="335"/>
+        <location filename="../SettingsDialog.qml" line="336"/>
         <source>Safe search</source>
         <translation>Ricerca sicura</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="395"/>
+        <location filename="../SettingsDialog.qml" line="396"/>
         <source>Screen orientation</source>
         <translation>Orientamento schermo</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="301"/>
+        <location filename="../SettingsDialog.qml" line="302"/>
         <source>Media player</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="277"/>
+        <location filename="../SettingsDialog.qml" line="278"/>
         <source>None</source>
         <translation>Nessuna</translation>
     </message>
@@ -893,7 +898,7 @@
         <translation type="obsolete">Feed Quattro</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="346"/>
+        <location filename="../SettingsDialog.qml" line="347"/>
         <source>Clear saved searches</source>
         <translation>Cancella ricerche salvate</translation>
     </message>
@@ -1205,7 +1210,7 @@
     <message>
         <location filename="../VideoInfoView.qml" line="443"/>
         <location filename="../VideoInfoView.qml" line="467"/>
-        <location filename="../VideoInfoView.qml" line="579"/>
+        <location filename="../VideoInfoView.qml" line="580"/>
         <source>You are not signed in to a YouTube account</source>
         <translation>Non hai effettuato l&apos;accesso con un account YouTube</translation>
     </message>
@@ -1257,17 +1262,17 @@
         <translation>Nessun Tag</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="591"/>
+        <location filename="../VideoInfoView.qml" line="592"/>
         <source>No comments</source>
         <translation>Nessun commento</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="591"/>
+        <location filename="../VideoInfoView.qml" line="592"/>
         <source> comments</source>
         <translation> commenti</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="684"/>
+        <location filename="../VideoInfoView.qml" line="685"/>
         <source>No related videos</source>
         <translation>Nessun video correlato</translation>
     </message>
@@ -1450,41 +1455,52 @@
         <translation type="obsolete">Luce</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="111"/>
+        <location filename="../main.qml" line="112"/>
         <source>Video(s) added to download queue</source>
         <translation>Video aggiunto(i) alla coda download</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="122"/>
+        <location filename="../main.qml" line="115"/>
+        <source>Video(s) already in download queue</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="126"/>
         <source>Audio track(s) added to download queue</source>
         <translation>Traccia(e) audio aggiunta(e) alla coda download</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="153"/>
+        <location filename="../main.qml" line="129"/>
+        <source>Audio track(s) already in download queue</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="160"/>
         <source>Video added to favourites</source>
         <translation>Video aggiunto ai preferiti</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="154"/>
+        <location filename="../main.qml" line="161"/>
         <source>Video added to playlist</source>
         <translation>Video aggiunto alla playlist</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="162"/>
+        <location filename="../main.qml" line="169"/>
         <source>New playlist created</source>
         <translation>Nuova playlist creata</translation>
     </message>
     <message>
+        <location filename="../main.qml" line="234"/>
         <source>Converting</source>
-        <translation type="obsolete">In Conversione</translation>
+        <translation>In Conversione</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="212"/>
+        <location filename="../main.qml" line="219"/>
         <source>Conversion of &apos;</source>
         <translation>Conversione di &apos;</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="212"/>
+        <location filename="../main.qml" line="219"/>
         <source>&apos; failed</source>
         <translation>&apos; fallita</translation>
     </message>
@@ -1493,32 +1509,32 @@
         <translation type="obsolete">Altà qualità</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="234"/>
         <source>Queued</source>
         <translation>In Coda</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="234"/>
         <source>Paused</source>
         <translation>In Pausa</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="234"/>
         <source>Downloading</source>
         <translation>In Download</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="234"/>
         <source>Failed</source>
         <translation>Fallito</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="396"/>
+        <location filename="../main.qml" line="416"/>
         <source>Most Recent</source>
         <translation>I Più Recenti</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="397"/>
+        <location filename="../main.qml" line="417"/>
         <source>Most Viewed</source>
         <translation>I Più Visti</translation>
     </message>
@@ -1526,32 +1542,32 @@
 <context>
     <name>mainscripts</name>
     <message>
-        <location filename="../scripts/mainscripts.js" line="146"/>
+        <location filename="../scripts/mainscripts.js" line="152"/>
         <source>My Channel</source>
         <translation>Il Mio Canale</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="161"/>
+        <location filename="../scripts/mainscripts.js" line="167"/>
         <source>Archive</source>
         <translation>Archivio</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="200"/>
+        <location filename="../scripts/mainscripts.js" line="206"/>
         <source>My Playlists</source>
         <translation>Le Mie Playlist</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="210"/>
+        <location filename="../scripts/mainscripts.js" line="216"/>
         <source>My Subscriptions</source>
         <translation>Le Mie Iscrizioni</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="223"/>
+        <location filename="../scripts/mainscripts.js" line="229"/>
         <source>Video Info</source>
         <translation>Info Video</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="233"/>
+        <location filename="../scripts/mainscripts.js" line="239"/>
         <source>Video Playback</source>
         <translation>Riproduzione Video</translation>
     </message>
@@ -1572,7 +1588,7 @@
         <translation type="obsolete">voto</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="246"/>
+        <location filename="../scripts/mainscripts.js" line="252"/>
         <source>Search </source>
         <translation>Cerca </translation>
     </message>
