@@ -28,9 +28,13 @@
         <translation type="obsolete">Multifunkcjonalny klient Youtube dla Noki N900. To jest eksperymentalne wydanie wykorzystującye QML. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</translation>
     </message>
     <message>
-        <location filename="../AboutDialog.qml" line="44"/>
         <source>cuteTube-QML - 0.7.3</source>
-        <translation type="unfinished">cuteTube-QML - 0.7.3 - PL</translation>
+        <translation type="obsolete">cuteTube-QML - 0.7.3 - PL</translation>
+    </message>
+    <message>
+        <location filename="../AboutDialog.qml" line="44"/>
+        <source>cuteTube-QML - 0.7.5</source>
+        <translation type="unfinished">cuteTube-QML - 0.7.5 - PL</translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
@@ -207,22 +211,22 @@
         <translation type="obsolete">Polski</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="189"/>
+        <location filename="../../../controller.cpp" line="222"/>
         <source>Video deleted from device</source>
         <translation>Plik wideo usunięty z urządzenia</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="192"/>
+        <location filename="../../../controller.cpp" line="225"/>
         <source>Unable to delete video</source>
         <translation>Nie można usunąć pliku wideo</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="196"/>
+        <location filename="../../../controller.cpp" line="229"/>
         <source>Video not found</source>
         <translation>Plik wideo nie znaleziony</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="251"/>
+        <location filename="../../../controller.cpp" line="284"/>
         <source>Copied to clipboard</source>
         <translation>Skopiowany do schowka</translation>
     </message>
@@ -415,12 +419,12 @@
 <context>
     <name>NotificationArea</name>
     <message>
-        <location filename="../NotificationArea.qml" line="50"/>
+        <location filename="../NotificationArea.qml" line="51"/>
         <source>No active downloads</source>
         <translation>Brak aktywnych pobrań </translation>
     </message>
     <message>
-        <location filename="../NotificationArea.qml" line="145"/>
+        <location filename="../NotificationArea.qml" line="146"/>
         <source>Downloads</source>
         <translation>Pobrania</translation>
     </message>
@@ -554,64 +558,64 @@
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../SettingsDialog.qml" line="194"/>
+        <location filename="../SettingsDialog.qml" line="195"/>
         <source>Your saved searches have been cleared</source>
         <translation>Twoje zapisane wyszukiwania zostały wyczyszczone</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="197"/>
+        <location filename="../SettingsDialog.qml" line="198"/>
         <source>Database error. Unable to clear searches</source>
         <translation>Błąd bazy danych. Nie można wyczyścić wyszukiwań</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="244"/>
+        <location filename="../SettingsDialog.qml" line="245"/>
         <source>Settings</source>
         <translation>Ustawienia</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="310"/>
+        <location filename="../SettingsDialog.qml" line="311"/>
         <source>Playback quality</source>
         <translation>Jakość odtwarzania</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="319"/>
+        <location filename="../SettingsDialog.qml" line="320"/>
         <source>Download quality</source>
         <translation>Jakość pobierania</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="285"/>
+        <location filename="../SettingsDialog.qml" line="286"/>
         <source>Start downloads</source>
         <translation>Uruchomienie pobierania</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="353"/>
+        <location filename="../SettingsDialog.qml" line="354"/>
         <source>Appearance</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="378"/>
+        <location filename="../SettingsDialog.qml" line="379"/>
         <source>System</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="386"/>
+        <location filename="../SettingsDialog.qml" line="387"/>
         <source>Download location</source>
         <translation>Miejsce pobierania</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="395"/>
+        <location filename="../SettingsDialog.qml" line="396"/>
         <source>Screen orientation</source>
         <translation>Orientacja ekranu</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="301"/>
+        <location filename="../SettingsDialog.qml" line="302"/>
         <source>Media player</source>
         <translation>Odtwarzacz</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="170"/>
-        <location filename="../SettingsDialog.qml" line="370"/>
-        <location filename="../SettingsDialog.qml" line="372"/>
+        <location filename="../SettingsDialog.qml" line="171"/>
+        <location filename="../SettingsDialog.qml" line="371"/>
+        <location filename="../SettingsDialog.qml" line="373"/>
         <source>Language</source>
         <translation>Język</translation>
     </message>
@@ -637,98 +641,103 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="43"/>
+        <location filename="../SettingsDialog.qml" line="44"/>
         <source>Russian</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="44"/>
+        <source>Portuguese</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="45"/>
         <source>Most recent</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="44"/>
+        <location filename="../SettingsDialog.qml" line="45"/>
         <source>Most viewed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="45"/>
+        <location filename="../SettingsDialog.qml" line="46"/>
         <source>Archive</source>
         <translation type="unfinished">Archiwum</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="45"/>
+        <location filename="../SettingsDialog.qml" line="46"/>
         <source>Latest subscription videos</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="46"/>
+        <location filename="../SettingsDialog.qml" line="47"/>
         <source>My uploads</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="46"/>
+        <location filename="../SettingsDialog.qml" line="47"/>
         <source>My favourites</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="122"/>
-        <location filename="../SettingsDialog.qml" line="173"/>
+        <location filename="../SettingsDialog.qml" line="123"/>
+        <location filename="../SettingsDialog.qml" line="174"/>
         <source>Network Proxy</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="146"/>
-        <location filename="../SettingsDialog.qml" line="312"/>
+        <location filename="../SettingsDialog.qml" line="147"/>
+        <location filename="../SettingsDialog.qml" line="313"/>
         <source>Playback Quality</source>
         <translation>Jakość odtwarzania</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="149"/>
-        <location filename="../SettingsDialog.qml" line="321"/>
+        <location filename="../SettingsDialog.qml" line="150"/>
+        <location filename="../SettingsDialog.qml" line="322"/>
         <source>Download Quality</source>
         <translation>Jakość pobierania</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="152"/>
-        <location filename="../SettingsDialog.qml" line="287"/>
+        <location filename="../SettingsDialog.qml" line="153"/>
+        <location filename="../SettingsDialog.qml" line="288"/>
         <source>Start Downloads</source>
         <translation>Uruchom pobieranie</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="161"/>
-        <location filename="../SettingsDialog.qml" line="397"/>
+        <location filename="../SettingsDialog.qml" line="162"/>
+        <location filename="../SettingsDialog.qml" line="398"/>
         <source>Screen Orientation</source>
         <translation>Orientacja ekranu</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="164"/>
-        <location filename="../SettingsDialog.qml" line="303"/>
+        <location filename="../SettingsDialog.qml" line="165"/>
+        <location filename="../SettingsDialog.qml" line="304"/>
         <source>Media Player</source>
         <translation>Odtwarzacz</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="411"/>
+        <location filename="../SettingsDialog.qml" line="412"/>
         <source>Widget</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="419"/>
+        <location filename="../SettingsDialog.qml" line="420"/>
         <source>Feed one</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="428"/>
+        <location filename="../SettingsDialog.qml" line="429"/>
         <source>Feed two</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="437"/>
+        <location filename="../SettingsDialog.qml" line="438"/>
         <source>Feed three</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="446"/>
+        <location filename="../SettingsDialog.qml" line="447"/>
         <source>Feed four</source>
         <translation type="unfinished"></translation>
     </message>
@@ -813,7 +822,7 @@
         <translation>Holenderski</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="43"/>
+        <location filename="../SettingsDialog.qml" line="44"/>
         <source>Polish</source>
         <translation>Polski</translation>
     </message>
@@ -826,90 +835,90 @@
         <translation type="obsolete">Wstrzymany</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="107"/>
+        <location filename="../SettingsDialog.qml" line="108"/>
         <source>Your settings have been saved</source>
         <translation>Twoje ustawienia zostały zapisane</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="112"/>
-        <location filename="../SettingsDialog.qml" line="155"/>
+        <location filename="../SettingsDialog.qml" line="113"/>
+        <location filename="../SettingsDialog.qml" line="156"/>
         <source>Download Path</source>
         <translation>Ścieżka pobierania</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="114"/>
+        <location filename="../SettingsDialog.qml" line="115"/>
         <source>Download Location</source>
         <translation>Miejsce Pobierania</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="158"/>
-        <location filename="../SettingsDialog.qml" line="337"/>
+        <location filename="../SettingsDialog.qml" line="159"/>
+        <location filename="../SettingsDialog.qml" line="338"/>
         <source>Safe Search</source>
         <translation>Bezpieczne wyszukiwanie</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="167"/>
-        <location filename="../SettingsDialog.qml" line="361"/>
-        <location filename="../SettingsDialog.qml" line="363"/>
+        <location filename="../SettingsDialog.qml" line="168"/>
+        <location filename="../SettingsDialog.qml" line="362"/>
+        <location filename="../SettingsDialog.qml" line="364"/>
         <source>Theme</source>
         <translation>Skórka</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="176"/>
-        <location filename="../SettingsDialog.qml" line="421"/>
+        <location filename="../SettingsDialog.qml" line="177"/>
+        <location filename="../SettingsDialog.qml" line="422"/>
         <source>Widget Feed One</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="179"/>
-        <location filename="../SettingsDialog.qml" line="430"/>
+        <location filename="../SettingsDialog.qml" line="180"/>
+        <location filename="../SettingsDialog.qml" line="431"/>
         <source>Widget Feed Two</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="182"/>
-        <location filename="../SettingsDialog.qml" line="439"/>
+        <location filename="../SettingsDialog.qml" line="183"/>
+        <location filename="../SettingsDialog.qml" line="440"/>
         <source>Widget Feed Three</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="185"/>
-        <location filename="../SettingsDialog.qml" line="448"/>
+        <location filename="../SettingsDialog.qml" line="186"/>
+        <location filename="../SettingsDialog.qml" line="449"/>
         <source>Widget Feed Four</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="268"/>
+        <location filename="../SettingsDialog.qml" line="269"/>
         <source>Network</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="276"/>
+        <location filename="../SettingsDialog.qml" line="277"/>
         <source>Network proxy</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="293"/>
+        <location filename="../SettingsDialog.qml" line="294"/>
         <source>Media</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="327"/>
+        <location filename="../SettingsDialog.qml" line="328"/>
         <source>YouTube searches</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="335"/>
+        <location filename="../SettingsDialog.qml" line="336"/>
         <source>Safe search</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="277"/>
+        <location filename="../SettingsDialog.qml" line="278"/>
         <source>None</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="346"/>
+        <location filename="../SettingsDialog.qml" line="347"/>
         <source>Clear saved searches</source>
         <translation>Wyczyść zapisane wyszukiwania</translation>
     </message>
@@ -1225,7 +1234,7 @@
     <message>
         <location filename="../VideoInfoView.qml" line="443"/>
         <location filename="../VideoInfoView.qml" line="467"/>
-        <location filename="../VideoInfoView.qml" line="579"/>
+        <location filename="../VideoInfoView.qml" line="580"/>
         <source>You are not signed in to a YouTube account</source>
         <translation>Nie jesteś zalogowany do swojego konta YouTube</translation>
     </message>
@@ -1277,17 +1286,17 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="591"/>
+        <location filename="../VideoInfoView.qml" line="592"/>
         <source>No comments</source>
         <translation>Brak komentarzy</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="591"/>
+        <location filename="../VideoInfoView.qml" line="592"/>
         <source> comments</source>
         <translation> komentarzy</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="684"/>
+        <location filename="../VideoInfoView.qml" line="685"/>
         <source>No related videos</source>
         <translation>Brak podobnych plików wideo</translation>
     </message>
@@ -1415,41 +1424,52 @@
         <translation type="obsolete">Jasny</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="111"/>
+        <location filename="../main.qml" line="112"/>
         <source>Video(s) added to download queue</source>
         <translation>Plik(i) wideo dodane do kolejki pobierania</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="122"/>
+        <location filename="../main.qml" line="115"/>
+        <source>Video(s) already in download queue</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="126"/>
         <source>Audio track(s) added to download queue</source>
         <translation>Plik(i) audio dodane do kolejki pobierania</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="153"/>
+        <location filename="../main.qml" line="129"/>
+        <source>Audio track(s) already in download queue</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="160"/>
         <source>Video added to favourites</source>
         <translation>Wideo dodane do ulubionych</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="154"/>
+        <location filename="../main.qml" line="161"/>
         <source>Video added to playlist</source>
         <translation>Wideo dodane do listy odtwarzania</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="162"/>
+        <location filename="../main.qml" line="169"/>
         <source>New playlist created</source>
         <translation>Utworzono nową listę odtwarzania</translation>
     </message>
     <message>
+        <location filename="../main.qml" line="234"/>
         <source>Converting</source>
-        <translation type="obsolete">Konwersja</translation>
+        <translation>Konwersja</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="212"/>
+        <location filename="../main.qml" line="219"/>
         <source>Conversion of &apos;</source>
         <translation>Konwersja &apos;</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="212"/>
+        <location filename="../main.qml" line="219"/>
         <source>&apos; failed</source>
         <translation>&apos; nieudana</translation>
     </message>
@@ -1458,32 +1478,32 @@
         <translation type="obsolete">Mobilny</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="234"/>
         <source>Queued</source>
         <translation>W Kolejce</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="234"/>
         <source>Paused</source>
         <translation>Wstrzymany</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="234"/>
         <source>Downloading</source>
-        <translation type="unfinished">Pobieranie</translation>
+        <translation>Pobieranie</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="234"/>
         <source>Failed</source>
-        <translation type="unfinished">Nieudany</translation>
+        <translation>Nieudany</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="396"/>
+        <location filename="../main.qml" line="416"/>
         <source>Most Recent</source>
         <translation>Ostatnio dodane</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="397"/>
+        <location filename="../main.qml" line="417"/>
         <source>Most Viewed</source>
         <translation>Najczęściej oglądane</translation>
     </message>
@@ -1495,32 +1515,32 @@
         <translation type="obsolete">Odtwarzacz</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="146"/>
+        <location filename="../scripts/mainscripts.js" line="152"/>
         <source>My Channel</source>
         <translation>Mój kanał</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="161"/>
+        <location filename="../scripts/mainscripts.js" line="167"/>
         <source>Archive</source>
         <translation>Archiwum</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="200"/>
+        <location filename="../scripts/mainscripts.js" line="206"/>
         <source>My Playlists</source>
         <translation>Moje listy odtwarzania</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="210"/>
+        <location filename="../scripts/mainscripts.js" line="216"/>
         <source>My Subscriptions</source>
         <translation>Moje Subskrybcje</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="223"/>
+        <location filename="../scripts/mainscripts.js" line="229"/>
         <source>Video Info</source>
         <translation>Informacja o Wideo</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="233"/>
+        <location filename="../scripts/mainscripts.js" line="239"/>
         <source>Video Playback</source>
         <translation>Odtwarzanie Wideo</translation>
     </message>
@@ -1545,7 +1565,7 @@
         <translation type="obsolete">oceny</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="246"/>
+        <location filename="../scripts/mainscripts.js" line="252"/>
         <source>Search </source>
         <translation>Wyszukaj </translation>
     </message>
