@@ -5,8 +5,8 @@
     <name>AboutDialog</name>
     <message>
         <location filename="../AboutDialog.qml" line="44"/>
-        <source>cuteTube-QML - 0.7.3</source>
-        <translation></translation>
+        <source>cuteTube-QML - 0.7.5</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
@@ -163,22 +163,22 @@
 <context>
     <name>Controller</name>
     <message>
-        <location filename="../../../controller.cpp" line="189"/>
+        <location filename="../../../controller.cpp" line="222"/>
         <source>Video deleted from device</source>
         <translation>Vídeo excluído do dispostivo</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="192"/>
+        <location filename="../../../controller.cpp" line="225"/>
         <source>Unable to delete video</source>
         <translation>Não foi possível excluir o vídeo</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="196"/>
+        <location filename="../../../controller.cpp" line="229"/>
         <source>Video not found</source>
         <translation>Não foi possível encontrar o vídeo</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="251"/>
+        <location filename="../../../controller.cpp" line="284"/>
         <source>Copied to clipboard</source>
         <translation>Copiado para Clipboard</translation>
     </message>
@@ -309,12 +309,12 @@
 <context>
     <name>NotificationArea</name>
     <message>
-        <location filename="../NotificationArea.qml" line="50"/>
+        <location filename="../NotificationArea.qml" line="51"/>
         <source>No active downloads</source>
         <translation>Sem downloads activos</translation>
     </message>
     <message>
-        <location filename="../NotificationArea.qml" line="145"/>
+        <location filename="../NotificationArea.qml" line="146"/>
         <source>Downloads</source>
         <translation>Downloads</translation>
     </message>
@@ -420,64 +420,64 @@
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../SettingsDialog.qml" line="194"/>
+        <location filename="../SettingsDialog.qml" line="195"/>
         <source>Your saved searches have been cleared</source>
         <translation>As suas pesquisas salvas foram limpas</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="197"/>
+        <location filename="../SettingsDialog.qml" line="198"/>
         <source>Database error. Unable to clear searches</source>
         <translation>Erro na base de dados. Impossível eliminar as pesquisas</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="244"/>
+        <location filename="../SettingsDialog.qml" line="245"/>
         <source>Settings</source>
         <translation>Definições</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="310"/>
+        <location filename="../SettingsDialog.qml" line="311"/>
         <source>Playback quality</source>
         <translation>Qualidade de reprodução</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="319"/>
+        <location filename="../SettingsDialog.qml" line="320"/>
         <source>Download quality</source>
         <translation>Qualidade de download</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="285"/>
+        <location filename="../SettingsDialog.qml" line="286"/>
         <source>Start downloads</source>
         <translation>Iniciar downloads</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="353"/>
+        <location filename="../SettingsDialog.qml" line="354"/>
         <source>Appearance</source>
         <translation>Aparência</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="378"/>
+        <location filename="../SettingsDialog.qml" line="379"/>
         <source>System</source>
         <translation>Sistema</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="386"/>
+        <location filename="../SettingsDialog.qml" line="387"/>
         <source>Download location</source>
         <translation>Localização de Downloads</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="395"/>
+        <location filename="../SettingsDialog.qml" line="396"/>
         <source>Screen orientation</source>
         <translation>Orientação do Ecrã</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="301"/>
+        <location filename="../SettingsDialog.qml" line="302"/>
         <source>Media player</source>
         <translation>Leitor Média</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="170"/>
-        <location filename="../SettingsDialog.qml" line="370"/>
-        <location filename="../SettingsDialog.qml" line="372"/>
+        <location filename="../SettingsDialog.qml" line="171"/>
+        <location filename="../SettingsDialog.qml" line="371"/>
+        <location filename="../SettingsDialog.qml" line="373"/>
         <source>Language</source>
         <translation>Língua</translation>
     </message>
@@ -488,73 +488,73 @@
         <translation>Alta Qualidade</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="43"/>
+        <location filename="../SettingsDialog.qml" line="44"/>
         <source>Russian</source>
         <translation>Russo</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="44"/>
+        <location filename="../SettingsDialog.qml" line="45"/>
         <source>Most recent</source>
         <translation>Mais recente</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="44"/>
+        <location filename="../SettingsDialog.qml" line="45"/>
         <source>Most viewed</source>
         <translation>Mais vistos</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="45"/>
+        <location filename="../SettingsDialog.qml" line="46"/>
         <source>Archive</source>
         <translation>Arquivos</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="45"/>
+        <location filename="../SettingsDialog.qml" line="46"/>
         <source>Latest subscription videos</source>
         <translation>Últimas subscrições de vídeos</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="46"/>
+        <location filename="../SettingsDialog.qml" line="47"/>
         <source>My uploads</source>
         <translation>Meus uploads</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="46"/>
+        <location filename="../SettingsDialog.qml" line="47"/>
         <source>My favourites</source>
         <translation>Meus favoritos</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="122"/>
-        <location filename="../SettingsDialog.qml" line="173"/>
+        <location filename="../SettingsDialog.qml" line="123"/>
+        <location filename="../SettingsDialog.qml" line="174"/>
         <source>Network Proxy</source>
         <translation>Proxy da Rede</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="146"/>
-        <location filename="../SettingsDialog.qml" line="312"/>
+        <location filename="../SettingsDialog.qml" line="147"/>
+        <location filename="../SettingsDialog.qml" line="313"/>
         <source>Playback Quality</source>
         <translation>Qualidade de Reprodução</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="149"/>
-        <location filename="../SettingsDialog.qml" line="321"/>
+        <location filename="../SettingsDialog.qml" line="150"/>
+        <location filename="../SettingsDialog.qml" line="322"/>
         <source>Download Quality</source>
         <translation>Qualidade de Download</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="152"/>
-        <location filename="../SettingsDialog.qml" line="287"/>
+        <location filename="../SettingsDialog.qml" line="153"/>
+        <location filename="../SettingsDialog.qml" line="288"/>
         <source>Start Downloads</source>
         <translation>Iniciar Downloads</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="161"/>
-        <location filename="../SettingsDialog.qml" line="397"/>
+        <location filename="../SettingsDialog.qml" line="162"/>
+        <location filename="../SettingsDialog.qml" line="398"/>
         <source>Screen Orientation</source>
         <translation>Orientação do Ecrã</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="164"/>
-        <location filename="../SettingsDialog.qml" line="303"/>
+        <location filename="../SettingsDialog.qml" line="165"/>
+        <location filename="../SettingsDialog.qml" line="304"/>
         <source>Media Player</source>
         <translation>Leitor Média</translation>
     </message>
@@ -650,120 +650,125 @@
         <translation>Holandês</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="43"/>
+        <location filename="../SettingsDialog.qml" line="44"/>
         <source>Polish</source>
         <translation>Polonês</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="107"/>
+        <location filename="../SettingsDialog.qml" line="44"/>
+        <source>Portuguese</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="108"/>
         <source>Your settings have been saved</source>
         <translation>As tuas definições foram salvas</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="112"/>
-        <location filename="../SettingsDialog.qml" line="155"/>
+        <location filename="../SettingsDialog.qml" line="113"/>
+        <location filename="../SettingsDialog.qml" line="156"/>
         <source>Download Path</source>
         <translation>Caminho dos Downloads</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="114"/>
+        <location filename="../SettingsDialog.qml" line="115"/>
         <source>Download Location</source>
         <translation>Localização dos Downloads</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="158"/>
-        <location filename="../SettingsDialog.qml" line="337"/>
+        <location filename="../SettingsDialog.qml" line="159"/>
+        <location filename="../SettingsDialog.qml" line="338"/>
         <source>Safe Search</source>
         <translation>Pesquisa Segura</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="167"/>
-        <location filename="../SettingsDialog.qml" line="361"/>
-        <location filename="../SettingsDialog.qml" line="363"/>
+        <location filename="../SettingsDialog.qml" line="168"/>
+        <location filename="../SettingsDialog.qml" line="362"/>
+        <location filename="../SettingsDialog.qml" line="364"/>
         <source>Theme</source>
         <translation>Tema</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="176"/>
-        <location filename="../SettingsDialog.qml" line="421"/>
+        <location filename="../SettingsDialog.qml" line="177"/>
+        <location filename="../SettingsDialog.qml" line="422"/>
         <source>Widget Feed One</source>
         <translation>Widget Feed Um</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="179"/>
-        <location filename="../SettingsDialog.qml" line="430"/>
+        <location filename="../SettingsDialog.qml" line="180"/>
+        <location filename="../SettingsDialog.qml" line="431"/>
         <source>Widget Feed Two</source>
         <translation>Widget Feed Dois</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="182"/>
-        <location filename="../SettingsDialog.qml" line="439"/>
+        <location filename="../SettingsDialog.qml" line="183"/>
+        <location filename="../SettingsDialog.qml" line="440"/>
         <source>Widget Feed Three</source>
         <translation>Widget Feed Três</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="185"/>
-        <location filename="../SettingsDialog.qml" line="448"/>
+        <location filename="../SettingsDialog.qml" line="186"/>
+        <location filename="../SettingsDialog.qml" line="449"/>
         <source>Widget Feed Four</source>
         <translation>Widget Feed Quatro</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="268"/>
+        <location filename="../SettingsDialog.qml" line="269"/>
         <source>Network</source>
         <translation>Rede</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="276"/>
+        <location filename="../SettingsDialog.qml" line="277"/>
         <source>Network proxy</source>
         <translation>Proxy da rede</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="293"/>
+        <location filename="../SettingsDialog.qml" line="294"/>
         <source>Media</source>
         <translation>Média</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="327"/>
+        <location filename="../SettingsDialog.qml" line="328"/>
         <source>YouTube searches</source>
         <translation>Pesquisas do YouTube</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="335"/>
+        <location filename="../SettingsDialog.qml" line="336"/>
         <source>Safe search</source>
         <translation>Pesquisa segura</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="411"/>
+        <location filename="../SettingsDialog.qml" line="412"/>
         <source>Widget</source>
         <translation>Widget</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="419"/>
+        <location filename="../SettingsDialog.qml" line="420"/>
         <source>Feed one</source>
         <translation>Feed um</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="428"/>
+        <location filename="../SettingsDialog.qml" line="429"/>
         <source>Feed two</source>
         <translation>Feed dois</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="437"/>
+        <location filename="../SettingsDialog.qml" line="438"/>
         <source>Feed three</source>
         <translation>Feed três</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="446"/>
+        <location filename="../SettingsDialog.qml" line="447"/>
         <source>Feed four</source>
         <translation>Feed quatro</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="277"/>
+        <location filename="../SettingsDialog.qml" line="278"/>
         <source>None</source>
         <translation>Nenhum</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="346"/>
+        <location filename="../SettingsDialog.qml" line="347"/>
         <source>Clear saved searches</source>
         <translation>Excluir pesquisas salvas</translation>
     </message>
@@ -1031,7 +1036,7 @@
     <message>
         <location filename="../VideoInfoView.qml" line="443"/>
         <location filename="../VideoInfoView.qml" line="467"/>
-        <location filename="../VideoInfoView.qml" line="579"/>
+        <location filename="../VideoInfoView.qml" line="580"/>
         <source>You are not signed in to a YouTube account</source>
         <translation>Não estás logado numa conta YouTube</translation>
     </message>
@@ -1083,17 +1088,17 @@
         <translation>Sem etiquetas</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="591"/>
+        <location filename="../VideoInfoView.qml" line="592"/>
         <source>No comments</source>
         <translation>Sem comentários</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="591"/>
+        <location filename="../VideoInfoView.qml" line="592"/>
         <source> comments</source>
         <translation> comentários</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="684"/>
+        <location filename="../VideoInfoView.qml" line="685"/>
         <source>No related videos</source>
         <translation>Sem vídeos relacionados</translation>
     </message>
@@ -1182,67 +1187,82 @@
 <context>
     <name>main</name>
     <message>
-        <location filename="../main.qml" line="111"/>
+        <location filename="../main.qml" line="112"/>
         <source>Video(s) added to download queue</source>
         <translation>Vídeo(s) adicionado(s) à fila de download</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="122"/>
+        <location filename="../main.qml" line="115"/>
+        <source>Video(s) already in download queue</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="126"/>
         <source>Audio track(s) added to download queue</source>
         <translation>Faixa(s) de áudio adicionada(s) á fila de download</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="153"/>
+        <location filename="../main.qml" line="129"/>
+        <source>Audio track(s) already in download queue</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="160"/>
         <source>Video added to favourites</source>
         <translation>Vídeo adicionado aos favoritos</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="154"/>
+        <location filename="../main.qml" line="161"/>
         <source>Video added to playlist</source>
         <translation>Vídeo adicionado à lista</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="162"/>
+        <location filename="../main.qml" line="169"/>
         <source>New playlist created</source>
         <translation>Nova lista criada</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="212"/>
+        <location filename="../main.qml" line="219"/>
         <source>Conversion of &apos;</source>
         <translation>Conversão de &apos;</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="212"/>
+        <location filename="../main.qml" line="219"/>
         <source>&apos; failed</source>
         <translation>&apos; falhou</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="234"/>
         <source>Queued</source>
         <translation>Em espera</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="234"/>
         <source>Paused</source>
         <translation>Pausado</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="234"/>
         <source>Downloading</source>
         <translation>Downloading</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="226"/>
+        <location filename="../main.qml" line="234"/>
         <source>Failed</source>
         <translation>Falhou</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="396"/>
+        <location filename="../main.qml" line="234"/>
+        <source>Converting</source>
+        <translation>Conversão</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="416"/>
         <source>Most Recent</source>
         <translation>Mais Recente</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="397"/>
+        <location filename="../main.qml" line="417"/>
         <source>Most Viewed</source>
         <translation>Mais Vistos</translation>
     </message>
@@ -1250,37 +1270,37 @@
 <context>
     <name>mainscripts</name>
     <message>
-        <location filename="../scripts/mainscripts.js" line="146"/>
+        <location filename="../scripts/mainscripts.js" line="152"/>
         <source>My Channel</source>
         <translation>Meu Canal</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="161"/>
+        <location filename="../scripts/mainscripts.js" line="167"/>
         <source>Archive</source>
         <translation>Arquivos</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="200"/>
+        <location filename="../scripts/mainscripts.js" line="206"/>
         <source>My Playlists</source>
         <translation>Minhas Listas</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="210"/>
+        <location filename="../scripts/mainscripts.js" line="216"/>
         <source>My Subscriptions</source>
         <translation>Minhas Subscrições</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="223"/>
+        <location filename="../scripts/mainscripts.js" line="229"/>
         <source>Video Info</source>
         <translation>Info. do Vídeo</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="233"/>
+        <location filename="../scripts/mainscripts.js" line="239"/>
         <source>Video Playback</source>
         <translation>Reprodução de Vídeo</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="246"/>
+        <location filename="../scripts/mainscripts.js" line="252"/>
         <source>Search </source>
         <translation>Pesquisar </translation>
     </message>
